#!/usr/bin/python
"""Print out available grass locations, mapsets, cells and image groups.

Usage: grassinfo [-D database] [-L location] [-M mapset]
                  [-l] [-m] [cellname]

Converted from libgrass5 v0.9.0 example program grassinfo.c by Frank Warmerdam.
Improved.
Command line parameters are different, though.

Copyright 2000 ImageLinks
Author: Bernhard Reiter <bernhard@intevation.de>
This script is part of libgrass5 and free software under the GNU LGPL.
"""

__version__="$Revision$"

from pylibgrass5 import *
import getopt
import sys


def main():
    gisdbase=None
    location=None
    mapset=None
    group_name=None
    user_cellname=None

    list_locations = 0
    list_mapsets = 0

    # handle command line arguments

    try:
        optlist, args=getopt.getopt(sys.argv[1:],"D:lL:mM:")
    except getopt.error,x:
        sys.stdout.write(x+"\n\n")
        print __doc__
        sys.exit(1)

    for opt in optlist:
        if opt[0] in ('-D',):
            gisdbase=opt[1]

        elif opt[0] in ('-L',):
            location=opt[1]

        elif opt[0] in ('-M',):
            mapset=opt[1]

        elif opt[0] in ('-l',):
            list_locations=1

        elif opt[0] in ('-m',):
            list_mapsets=1

        else:
            # should not happen!
            print "Program inconsistancy detected! Bailing out..."
            sys.exit(10)

    if len(args)>1:
        sys.stdout.write("Only one cellname allowed!\n\n")
        print__doc__
        sys.exit(1)
    else:
        if len(args)==1:
            user_cellname=args[0]

    # if we just have the database given, we can only list the locations.
    #if gisdbase and not location:
    #    list_locations=1

    
    # Initialize base on the selected (or default) mapset.
    error=G_gisinit_2("grassinfo.py",gisdbase,location,mapset)

    if list_locations:
        list=G_fetch_list_locations(gisdbase)
        print "Possible location names:"
        for location in list:
            print location

    if list_mapsets:
        if location:
            list=G_fetch_list_mapsets(None)
            print "Possible mapset names:"
            for map in list:
                print map
        else:
            sys.stdout.write("Warning: "+\
                "Can only list mapsets, if location is known.\n")
            sys.exit(2)


    # we might be done here
    if list_mapsets or list_locations:
        sys.exit(0)


    if error and not user_cellname:
        sys.stdout.write("Unable to initialize database access, "+\
                         "no valid .grassrc5\n")
        sys.exit(1)

    # Did the user select a cell file?  If not, list available ones. 
    if not user_cellname:
        cellhds=G_fetch_list_element("cellhd","")
        print "Possible cell names:"
        for cellhd in cellhds:
            print cellhd

        g=G_fetch_list_element("group", "")
        print "Possible imagery group names:"
        for group in g:
            print group

        sys.exit(0)

    # FIXME open cell and show info

main()
